@@ -65,16 +65,20 @@ class Client:
     def get_bearer_token(self):
         return self.cloud_credential.bearer_token
 
+    async def get_access_key_id_async(self):
+        if hasattr(self.cloud_credential, 'get_access_key_id'):
+            return self.cloud_credential.get_access_key_id()
+        else:
+            return
 
-class AioClient(Client):
-    @attribute_error_return_none
-    async def get_access_key_id(self):
-        return self.cloud_credential.get_access_key_id()
+    async def get_access_key_secret_async(self):
+        if hasattr(self.cloud_credential, 'get_access_key_secret'):
+            return self.cloud_credential.get_access_key_secret()
+        else:
+            return
 
-    @attribute_error_return_none
-    async def get_access_key_secret(self):
-        return self.cloud_credential.get_access_key_secret()
-
-    @attribute_error_return_none
-    async def get_security_token(self):
-        return self.cloud_credential.get_security_token()
+    async def get_security_token_async(self):
+        if hasattr(self.cloud_credential, 'get_security_token'):
+            return self.cloud_credential.get_security_token()
+        else:
+            return
